================
LibRapid NDarray
================

The poweful LibRapid n-dimensional array library, written
in C++

Documentation
=============

.. doxygenclass:: librapid::ndarray::basic_ndarray
	:members:

.. doxygenfunction:: librapid::ndarray::add
.. doxygenfunction:: librapid::ndarray::sub
.. doxygenfunction:: librapid::ndarray::mul
.. doxygenfunction:: librapid::ndarray::div

.. doxygenfunction:: librapid::ndarray::exp

.. doxygenfunction:: librapid::ndarray::sin
.. doxygenfunction:: librapid::ndarray::cos
.. doxygenfunction:: librapid::ndarray::tan

.. doxygenfunction:: librapid::ndarray::asin
.. doxygenfunction:: librapid::ndarray::acos
.. doxygenfunction:: librapid::ndarray::atan

.. doxygenfunction:: librapid::ndarray::sinh
.. doxygenfunction:: librapid::ndarray::cosh
.. doxygenfunction:: librapid::ndarray::tanh

.. doxygenfunction:: librapid::ndarray::reshape